AWS provide S3 web service storage to easily store and retrieve data.
Access to S3 bucket can enable access control and implement few security
settings. S3 bucket has been behind several high profile data
compromises and are a common misconfiguration.

A publicly accessible AWS S3 bucket was detected with potentially
sensitive information. The information was detected as the bucket
enables file listing and attacker can navigate all content in the
bucket.
